==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/BinArray/AllocUBA.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95allocUBA_35	((void*)startLabel+12)
#define CT_v197	((void*)startLabel+44)
#define F0_NHC_46BinArray_46hs_95allocUBA_35	((void*)startLabel+52)
#define FN_NHC_46BinArray_46hs_95allocUBA	((void*)startLabel+64)
#define CT_v199	((void*)startLabel+88)
#define CF_NHC_46BinArray_46hs_95allocUBA	((void*)startLabel+96)
#define CT_v201	((void*)startLabel+156)
#define FN_LAMBDA194	((void*)startLabel+192)
#define CT_v203	((void*)startLabel+216)
#define F0_LAMBDA194	((void*)startLabel+224)
#define ST_v200	((void*)startLabel+232)
#define ST_v202	((void*)startLabel+254)
#define ST_v198	((void*)startLabel+282)
#define ST_v196	((void*)startLabel+307)
extern Node TM_NHC_46BinArray[];
void FR_NHC_46BinArray_46hs_95allocUBA_35(void);
extern Node TM_NHC_46BinArray[];
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node TM_NHC_46BinArray[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_NHC_46BinArray[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v197)
,	/* FN_NHC_46BinArray_46hs_95allocUBA_35: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46BinArray_46hs_95allocUBA_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100022
, useLabel(ST_v196)
,	/* CT_v197: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46BinArray_46hs_95allocUBA_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95allocUBA_35),2)
, bytes2word(0,0,0,0)
, useLabel(CT_v199)
,	/* FN_NHC_46BinArray_46hs_95allocUBA: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100022
, useLabel(ST_v198)
,	/* CT_v199: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95allocUBA: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95allocUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46BinArray_46hs_95allocUBA_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v201)
,};
Node FN_NHC_46BinArray_46allocUBA[] = {
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_I5,PUSH_HEAP,HEAP_CVAL_P1,6)
, bytes2word(HEAP_OFF_N1,6,HEAP_OFF_N1,3)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 130001
, useLabel(ST_v200)
,	/* CT_v201: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46BinArray_46allocUBA[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46allocUBA),2)
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95allocUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA194),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v203)
,	/* FN_LAMBDA194: (byte 0) */
  useLabel(TMSUB_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 140013
, useLabel(ST_v202)
,	/* CT_v203: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA194: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA194),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* ST_v200: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,97,108,108)
, bytes2word(111,99,85,66)
,	/* ST_v202: (byte 2) */
  bytes2word(65,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,65,114,114)
, bytes2word(97,121,46,97)
, bytes2word(108,108,111,99)
, bytes2word(85,66,65,58)
, bytes2word(49,52,58,49)
,	/* ST_v198: (byte 2) */
  bytes2word(51,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,65,114,114)
, bytes2word(97,121,46,104)
, bytes2word(115,95,97,108)
, bytes2word(108,111,99,85)
,	/* ST_v196: (byte 3) */
  bytes2word(66,65,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(104,115,95,97)
, bytes2word(108,108,111,99)
, bytes2word(85,66,65,35)
, bytes2word(0,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_allocUBA" NHC.BinArray.hs_allocUBA# 2 :: Prelude.Int -> Prelude.Int -> FFI.ForeignObj */
extern void* hs_allocUBA(HsInt,HsInt);
#ifdef PROFILE
static SInfo pf_hs_allocUBA = {"NHC.BinArray","NHC.BinArray.hs_allocUBA#","FFI.ForeignObj"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95allocUBA_35) {
  NodePtr nodeptr;
  void* result;
  HsInt arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (HsInt)GET_INT_VALUE(nodeptr);
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_allocUBA(arg1,arg2);

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_hs_allocUBA);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/BinArray/AllocUBA.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95allocUBA_35	((void*)startLabel+12)
#define CT_v201	((void*)startLabel+44)
#define F0_NHC_46BinArray_46hs_95allocUBA_35	((void*)startLabel+52)
#define FN_NHC_46BinArray_46hs_95allocUBA	((void*)startLabel+64)
#define CT_v203	((void*)startLabel+88)
#define CF_NHC_46BinArray_46hs_95allocUBA	((void*)startLabel+96)
#define CT_v205	((void*)startLabel+156)
#define FN_LAMBDA198	((void*)startLabel+192)
#define CT_v207	((void*)startLabel+216)
#define F0_LAMBDA198	((void*)startLabel+224)
#define ST_v204	((void*)startLabel+232)
#define ST_v206	((void*)startLabel+254)
#define ST_v202	((void*)startLabel+288)
#define ST_v200	((void*)startLabel+313)
extern Node TM_NHC_46BinArray[];
void FR_NHC_46BinArray_46hs_95allocUBA_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_NHC_46BinArray[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v201)
,	/* FN_NHC_46BinArray_46hs_95allocUBA_35: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46BinArray_46hs_95allocUBA_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100001
, useLabel(ST_v200)
,	/* CT_v201: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46BinArray_46hs_95allocUBA_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95allocUBA_35),2)
, bytes2word(0,0,0,0)
, useLabel(CT_v203)
,	/* FN_NHC_46BinArray_46hs_95allocUBA: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100001
, useLabel(ST_v202)
,	/* CT_v203: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95allocUBA: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95allocUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46BinArray_46hs_95allocUBA_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v205)
,};
Node FN_NHC_46BinArray_46allocUBA[] = {
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_I5,PUSH_HEAP,HEAP_CVAL_P1,6)
, bytes2word(HEAP_OFF_N1,6,HEAP_OFF_N1,3)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 130001
, useLabel(ST_v204)
,	/* CT_v205: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46BinArray_46allocUBA[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46allocUBA),2)
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95allocUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA198),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v207)
,	/* FN_LAMBDA198: (byte 0) */
  useLabel(TMSUB_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 140013
, useLabel(ST_v206)
,	/* CT_v207: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA198: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA198),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* ST_v204: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,97,108,108)
, bytes2word(111,99,85,66)
,	/* ST_v206: (byte 2) */
  bytes2word(65,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,65,114,114)
, bytes2word(97,121,46,97)
, bytes2word(108,108,111,99)
, bytes2word(85,66,65,58)
, bytes2word(49,52,58,49)
, bytes2word(51,45,49,52)
,	/* ST_v202: (byte 4) */
  bytes2word(58,51,50,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(97,108,108,111)
, bytes2word(99,85,66,65)
,	/* ST_v200: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,104,115)
, bytes2word(95,97,108,108)
, bytes2word(111,99,85,66)
, bytes2word(65,35,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_allocUBA" NHC.BinArray.hs_allocUBA# 2 :: Prelude.Int -> Prelude.Int -> FFI.ForeignObj */
extern void* hs_allocUBA(HsInt,HsInt);
#ifdef PROFILE
static SInfo pf_NHC_46BinArray_46hs_95allocUBA_35 = {"NHC.BinArray","NHC.BinArray.hs_allocUBA#","FFI.ForeignObj"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95allocUBA_35) {
  NodePtr nodeptr;
  void* result;
  HsInt arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (HsInt)GET_INT_VALUE(nodeptr);
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_allocUBA(arg1,arg2);

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_NHC_46BinArray_46hs_95allocUBA_35);
  C_RETURN(nodeptr);
}
